@@ -5,7 +5,7 @@ FL1991 <- function(dmi=FALSE,url="http://web.dmi.dk/fsweb/solarterrestrial/suncl
     meta <- L[1:s1]
     s2 <- grep("-----------",L)
     col.names <- c("Epoch","Notes","L","L121","L12221","Cntr.Year")
-    widths <- c(8,6,4,6,7,10)
+    widths <- c(8,4,6,6,7,10)
     scl1=read.fwf(url,skip=s1,nrows=s2[1]-s1-1,
       col.names=col.names,widths=widths,as.is=TRUE)
     s3 <- grep("Solar cycle data for maxima",L)
@@ -22,7 +22,7 @@ FL1991 <- function(dmi=FALSE,url="http://web.dmi.dk/fsweb/solarterrestrial/suncl
     attr(fl1991,'url') <- url
     attr(fl1991,'solmax') <- scl3
   } else {
-    data(fl1991,env=environment())
+    data(fl1991,envir=environment())
   }
 
   plot(fl1991$Cntr.Year,fl1991$L,type="b",pch=19)
